@@ -1,7 +1,7 @@
-from PythonPals.Button import *
-#import Button
-from PythonPals.questions import *
-#import questions
+#from PythonPals.Button import *
+import Button
+#from PythonPals.questions import *
+import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
